/**
  *  \file client/widgets/billdisplay.h
  *  \brief WBillDisplay and WBillTotalDisplay widgets
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_BILLDISPLAY_H
#define PCC_V2_CLIENT_WIDGETS_BILLDISPLAY_H

#include <vector>
#include "ui/listbox.h"
#include "game/cost.h"
#include "cpluslib/ptrvector.h"

/** Item for a bill. Contains an item, its cost and count. */
struct WBillItem {
    int      id;              ///< User-specified item identifier.
    string_t item_name;       ///< Name of item.
    GCost    item_cost;       ///< Cost of all items.
    int      display_mult;    ///< Multiplier to display.

    WBillItem(int id, string_t item_name, const GCost& item_cost, int display_mult)
        : id(id),
          item_name(item_name),
          item_cost(item_cost),
          display_mult(display_mult)
        { }
};

/** A bill. */
typedef ptr_vector<WBillItem> WBill;

/** Display a bill. The bill can behave as a static piece, in which
    case it should have the same number of lines on display as the
    actual bill has. It can also behave as a (scrollable) list with
    each item selectable.

    The bill displays a Money, Tri, Dur, and Mol columns. The Money
    column includes supply costs. Actual supply costs are only needed
    for Fleet Cost Comparison when ship fighters are counted.

    This widget also displays a headline. A footer can be provided by
    WBillTotalDisplay. */
class WBillDisplay : public UIListbox {
    const WBill& bill;
    bool is_list;
 public:
    WBillDisplay(int id, int nlines, bool is_list, const WBill& bill);
    void drawContent(GfxCanvas& can);
    void drawPart(GfxCanvas& can, int from, int to);
    void update();

    void doExport();
};

/** Display a bill's total. This displays a divider line, followed by
    the totals, followed by an optional line containing remaining
    resources. Like for WBillDisplay, money and supplies are treated
    the same, although we display whether the remainder/missing is a
    money or supply count. */
class WBillTotalDisplay : public UIWidget {
    const WBill& bill;
    GCost have;
    bool has_compare;
 public:
    WBillTotalDisplay(const WBill& bill);
    WBillTotalDisplay(const GCost& have, const WBill& bill);

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);

    void setAvailableResources(const GCost& have);
    void update();
};

#endif
