/**
  *  \file client/widgets/histlist.h
  *  \brief History Ship Selection
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_HISTLIST_H
#define PCC_V2_CLIENT_WIDGETS_HISTLIST_H

#include "game/coord.h"
#include "cpluslib/smallset.h"
#include "client/widgets/objlist.h"
#include "ui/widgets/abstractbutton.h"
#include "ui/widgets/button.h"

class GUniverse;

/** History ship selection. This describes a selection of history
    ships for display. It is manipulated by a WHistoryShipControl, and
    used by WHistoryShipList to filter display. */
struct WHistoryShipSelection {
    enum Mode {
        AllShips,
        LocalShips,
        ExactShips,
        ForeignShips,
        TeamShips,
        EnemyShips,
        OwnShips
    };
    enum Sort {
        ById,
        ByOwner,
        ByHull,
        ByAge,
        ByName
    };
    enum {
        ModeMax = OwnShips,
        SortMax = ByName
    };

    Mode mode;
    Sort sortOrder;
    GPoint location;

    void buildList(GObjectList& list, const GUniverse& univ) const;
    int getShipLastTurn(const GUniverse& univ, int sid) const;
    SmallSet<Mode> getVisibleModes(const GUniverse& univ) const;
    Mode getInitialMode(const GUniverse& univ);

    string_t getModeName(Mode mode) const;
    string_t getModeName() const;
    static string_t getSortName(Sort sort);
    string_t getSortName() const;
};

/** History ship list. Displays a list of history ships as selected by
    a WHistoryShipSelection. */
class WHistoryShipList : public WObjectList {
    WHistoryShipSelection& config;
    GObjectList& list;

 public:
    WHistoryShipList(int id, int lines, int width, GObjectList& list, WHistoryShipSelection& config);
    ~WHistoryShipList();

    string_t getInfoForObject(GObjectReference id);

    void updateList();
};

class WHistoryShipControl : public UIBaseComplexWidget {
    WHistoryShipSelection& config;
    UIButton btn_d;

    void onClick();
 public:
    WHistoryShipControl(WHistoryShipSelection& config);
    ~WHistoryShipControl();

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);
    void onResize(GfxRect oldsize, bool by_layout);
    bool handleEvent(const UIEvent& e, bool second_pass);

    Signal0 sig_changed;
};

#endif
