/**
  *  \file resmgr/res-cc1.h
  *  \brief Resource Provider for PCC 1.x ".res" files
  *
  *  This provides a class to read ".res" files, and a Resource
  *  Provider to use it with the resource manager.
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_RESMGR_RES_CC1_H
#define PCC_V2_RESMGR_RES_CC1_H

#include "resmgr/resmgr.h"
#include "io/io.h"

/** PCC 1.x resource stream. Provides a stream that can read from a
    ".res" file.

    Use seekId(nn) to open a particular member of the resource file. 
    Then, all further accesses behave as if this stream were just the
    requested member. */
class ResourceStream : public SubStreamBase {
    /** Resource Directory Entry. */
    struct Entry {
        uint16    id;
        uint32    pos;
        uint32    len;
        
        static const TStructureParser parser[];
        enum { size = 10, count = 3 };
    };
    /** Resource File Header. */
    struct Header {
        uint16    magic;
        uint32    dirpos;
        uint16    nentries;
        static const TStructureParser parser[];
        enum { size = 8, count = 3 };
    };
    Header header;
    Buffer<Entry> rd;
    Ptr<Stream> worker;
 public:
    ResourceStream(Ptr<Stream> worker);
    ~ResourceStream();
    bool seekId(uint16 id);
};

/** PCC 1.x resource provider.

    Provides:
    - res::ship(n)
    - res::base(n)
    - res::vcr_ftr(n)
    - res::planet(n)
    - "res(n)" for raw picture access */
class ResProviderResFile : public ResSimpleProvider {
    Ptr<ResourceStream> res;
 public:
    ResProviderResFile(Ptr<Stream> s);
    ResProviderResFile(string_t name);
    ~ResProviderResFile();

    Ptr<GfxPixmap> loadPixmap(ResId id);
};

#endif
