/**
  *  \file ui/widgets/cardgroup.h
  *  \brief UICardGroup widget
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_CARDGROUP_H
#define PCC_V2_UI_WIDGETS_CARDGROUP_H

#include "ui/ui.h"

/** \class UICardGroup
    \brief Group containing widgets of which only one is visible at a time

    An UICardGroup can contain a number of child widgets with distinct
    widget Ids. Of these, only the focused widget is displayed; the
    others will be invisible. They will also not receive events.

    In order to change the displayed widget, change the focus.
    UICardGroup does not contain any provisions to do that. Another
    widget like UICardGroupTab must do that. */
class UICardGroup : public UIBaseWidget {
    void    onFocusChange(int);
 public:
    UICardGroup(int id = 0);
    ~UICardGroup();

    virtual void          drawEverything(GfxCanvas& canvas);
    virtual void          drawContent(GfxCanvas& canvas);
    virtual void          drawBelow(UIBaseWidget& child, GfxCanvas& canvas);
    virtual GfxCanvas&    getCanvasFor(UIBaseWidget& child, ObjectHolder& mgr);

    virtual bool          handleEvent(const UIEvent& event, bool second_pass);  // can be overridden in child

    virtual void          onAddRemoveChild(UIBaseWidget& the_widget, bool added);

    virtual void          onChildResize(UIBaseWidget& child, GfxRect oldsize);

    virtual void          onResize(GfxRect oldsize, bool by_layout);
    virtual void          getLayoutInfo(LayoutInfo&);

    void add(UIBaseWidget& w);
};

#endif
