/**
  *  \file ui/widgets/framegroup.cc
  *  \brief UIFrameGroup widget
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/framegroup.h"
#include "ui/util.h"
#include "ui/layout.h"

/** \class UIFrameGroup
    \brief Framed Group

    This widget is like UIGroup, but it will draw a "down" frame
    around its child widgets. */

/** Constructor.
    \param lay   Layout for content
    \param frame Frame width (border+padding). Use 1 (default) to
                 make the contained widget fit evenly within
                 the frame. */
UIFrameGroup::UIFrameGroup(UILayoutManager& lay, int frame)
    : UILayoutableWidget(lay), frame(frame)
{ }

void
UIFrameGroup::drawContent(GfxCanvas& can)
{
    drawFrameDown(can, getExtent());
    can.update(getExtent());
}

void
UIFrameGroup::adjustSize(GfxRect& size, bool to_inner)
{
    if (to_inner)
        size.grow(-frame, -frame);
    else
        size.grow(frame, frame);
}

/** Wrap a single widget in a UIFrameGroup.
    \param h Object holder
    \param widget Widget to wrap
    \return UIFrameGroup wrapping the widget */
UIFrameGroup&
UIFrameGroup::wrap(ObjectHolder& h, UIBaseWidget& widget)
{
    UIFrameGroup& fg = h.add(new UIFrameGroup(UIHBoxLayout::instance0));
    fg.add(widget);
    return fg;
}
